;-------------------------------------------------------------------------------
; Script name:
;       ct_helper
;
; Script Function:
;       Script facilitate use of cleartool in pspad editor.
;
;   Copyright (C) 2008, 2009 Alesc
;   This program is free software: you can redistribute it and/or modify
;   it under the terms of the GNU General Public License.
;-------------------------------------------------------------------------------

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input  ; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.
#SingleInstance force

InitCtHelper()

return

;-------------------------------------------------------------------------------
; lsvtree -g
;-------------------------------------------------------------------------------
#t::
progress_title = Lsvtree -g
Progress, P10 b1 %progSizes% CBblue, Get selected, %title% - %progress_title%, Lsvtree
selected := GetSelectedTxt()

ProgressUpdate(20, "")
; if something selected
if selected
{
    ProgressUpdate(30, "Searching file path")
    filename := FindPath(selected, SRC_PATH)
    if filename =
        goto failed_progress
}
; else instruct pspad to get you a filename
else
{
    ProgressUpdate(30, "Getting filename")
    if GetPSPCaretPos(filename, ycaret, xcaret) = HOT_ERR
        goto failed_progress
}

ProgressUpdate(60, "Lsvtree -g")
if RunCtCmdWin("lsvtree -g """ . filename . """") = HOT_ERR
    goto failed_progress

ProgressUpdate(100, "Done")
Progress, Off
return

;-------------------------------------------------------------------------------
; diff -pre -g
;-------------------------------------------------------------------------------
#d::
progress_title = diff -pre -g
Progress, P10 b %progSizes% CBblue, Get selected, %title% - %progress_title%, Lsvtree
selected := GetSelectedTxt()

ProgressUpdate(20, "")
if selected
{
    ProgressUpdate(30, "Searching file path")
    filename := FindPath(selected, SRC_PATH)
    if filename =
        goto failed_progress
}
else
{
    ProgressUpdate(30, "Getting filename")
    if GetPSPCaretPos(filename, ycaret, xcaret) = HOT_ERR
        goto failed_progress
}

ProgressUpdate(60, "Diff pre g")
if RunCtCmdWin("diff -pre -g """ . filename . """") = HOT_ERR
    goto failed_progress

ProgressUpdate(100, "Done")
Progress, Off
return

;-------------------------------------------------------------------------------
; checkout unreserved -nc
;-------------------------------------------------------------------------------
#c::
progress_title = Checkout
Progress, P10 b %progSizes% CBblue, Get selected, %title% - %progress_title%, Checkout
selected := GetSelectedTxt()

ProgressUpdate(20, "")
if selected
{
    ProgressUpdate(30, "Searching file path")
    filename := FindPath(selected, SRC_PATH)
    if filename =
        goto failed_progress
}
else
{
    ProgressUpdate(30, "Getting filename")
    if GetPSPCaretPos(filename, ycaret, xcaret) = HOT_ERR
        goto failed_progress
}

ProgressUpdate(60, "co -unreserved -nc")
if RunCtCmd("co -unreserved -nc """ . filename . """") = HOT_ERR
    goto failed_progress

ProgressUpdate(90, "Updating pspad")
ExecPSPFunc("runPSPadAction(aReOpen)")

ProgressUpdate(100, "Done")
Progress, Off
return

;-------------------------------------------------------------------------------
; undocheckout -rm
;-------------------------------------------------------------------------------
#n::
progress_title = Undocheckout
Progress, P10 b %progSizes% CBblue, Get selected, %title% - %progress_title%, Undocheckout
selected := GetSelectedTxt()

ProgressUpdate(20, "")
if selected
{
    ProgressUpdate(30, "Searching file path")
    filename := FindPath(selected, SRC_PATH)
    if filename =
        goto failed_progress
}
else
{
    ProgressUpdate(30, "Getting filename")
    if GetPSPCaretPos(filename, ycaret, xcaret) = HOT_ERR
        goto failed_progress
}

ProgressUpdate(60, "unco -rm")
if RunCtCmd("unco -rm """ . filename . """") = HOT_ERR
    goto failed_progress

ProgressUpdate(90, "Updating pspad")
ExecPSPFunc("runPSPadAction(aReOpen)")

ProgressUpdate(100, "Done")
Progress, Off
return

ProgressUpdate(new_level, new_action)
{
    global

    if new_level
        progress_level = %new_level%
    if new_action
        progress_action = %new_action%
    Progress, %progress_level%, %progress_action%
}
;---------------------------------------
; InitCtHelper
;
; Arguments: None
;
; Returns:
;   nothing
;
; Description:
;   Initializes menu and all global 
;   variables needed.
;---------------------------------------
InitCtHelper()
{
    global
    InitCORElib()

    title = Ct Helper
    version = 0.4
    ct_icon = .\resources\helper_icon.ico
    iniCt = ct_helper.ini

    options_GUIhandle = 2
    about_GUIhandle = 3

    ; get monitor work area and set progress bar X Y H W
    SysGet, workArea, MonitorWorkArea, 0
    progW = 200
    progH = 80
    progX := workAreaRight - progW
    progY := workAreaBottom - progH
    progSizes = W%progW% H%progH% X%progX% Y%progY%

    ; custom try menu
    menu, tray, NoStandard
    menu, tray, add, Options..., menuHandler
    menu, tray, add, Reload, menuHandler
    menu, tray, add
    menu, tray, add, Help, menuHandler
    menu, tray, add, Hint, menuHandler
    menu, tray, add, About..., menuHandler
    menu, tray, add
    menu, tray, add, Exit, menuHandler
    menu, tray, tip, %title% %version%
    menu, tray, icon, %ct_icon%

    ; shortcut for calling PSPad javascript hots.js
    ; ( default: Ctrl+Alt+G )
    IniRead, PSP_ACTION_KEY, %iniCt%, PSPad settings, Hots hotkey

    IniRead, SRC_PATH, %iniCt%, Program settings, Source path

    InitPSPlib(PSP_ACTION_KEY, "hots")
    InitCClib()

    if CheckOptions() = HOT_ERR
        CreateOptionsGUI()

    return
}
;---------------------------------------
; CheckOptions
;
; Arguments: None
;
; Returns:
;   HOT_ERR / HOT_OK
;
; Description
;   Checks if options are set 
;   at least a little bit correctly
;---------------------------------------
CheckOptions()
{
    global
    local errors = 0

    hotsHotkeyPicflag := "green.png"
    srcPathPicflag := "green.png"

    if (PSP_ACTION_KEY = "")
    {
        hotsHotkeyPicflag := "red.png"
        opt_errors += 1
    }
    IfNotExist, %SRC_PATH%
    {
        srcPathPicflag := "red.png"
        errors += 1
    }

    if errors > 0
        return %HOT_ERR%

    return %HOT_OK%
}

failed_progress:
    Progress, Off
    Progress, P%progress_level% b1 %progSizes% CBred, %progress_action% Failed, %title% - %progress_title%
    Sleep, 1000
    Progress, Off
return

HelpStart()
{
    Run, readme.txt
}

menuHandler:
if (A_ThisMenuItem = "Options...")
    CreateOptionsGUI()
else if (A_ThisMenuItem = "Reload")
    Reload
else if (A_ThisMenuItem = "Help")
    HelpStart()
else if (A_ThisMenuItem = "Hint")
    HintDisplay(HINT)
else if (A_ThisMenuItem = "About...")
    AboutCtHelper()
else if (A_ThisMenuItem = "Exit")
    ExitApp
return

#Include %A_ScriptDir%\includes\core_lib.ahk
#Include %A_ScriptDir%\includes\psp_lib.ahk
#Include %A_ScriptDir%\includes\cc_lib.ahk
#Include %A_ScriptDir%\includes\ct_gui.ahk
